@@ -26,7 +26,7 @@ MODE_LOCK_DOOR = 2
 MODE_OPENER_DOOR = 2
 MODE_OPENER_CONTINUOUS = 3
 
-# https://developer.nuki.io/page/nuki-bridge-http-api-1-10/4/#heading--lock-states
+# https://developer.nuki.io/page/nuki-bridge-http-api-1-11/4/#heading--lock-states
 STATE_LOCK_UNCALIBRATED = 0
 STATE_LOCK_LOCKED = 1
 STATE_LOCK_UNLOCKING = 2
@@ -41,4 +41,14 @@ STATE_LOCK_UNDEFINED = 255
 STATE_OPENER_UNTRAINED = 0
 STATE_OPENER_ONLINE = 1
 STATE_OPENER_RTO_ACTIVE = 3
-STATE_OPENER_OPENER_OPEN = 5
+STATE_OPENER_OPEN = 5
+STATE_OPENER_OPENING = 7
+STATE_OPENER_BOOT_RUN = 253
+STATE_OPENER_UNDEFINED = 255
+
+# https://developer.nuki.io/page/nuki-bridge-http-api-1-11/4/#heading--doorsensor-states
+STATE_DOORSENSOR_DEACTIVATED = 1
+STATE_DOORSENSOR_CLOSED = 2
+STATE_DOORSENSOR_OPENED = 3
+STATE_DOORSENSOR_UNKNOWN = 4
+STATE_DOORSENSOR_CALIBRATING = 5
